@@ -36,25 +36,14 @@ def import_schema_lamin_root_api():
         lamindb.schema._import_schema()
 
 
-def persist_check_reload_schema(isettings: InstanceSettings):
-    # check whether we're switching from sqlite to postgres or vice versa
-    # if we do, we need to re-import the schema modules to account for differences
-    check = False
-
-    if settings._instance_exists:  # this is needed prior to import
-        if settings.instance.dialect == "sqlite" and isettings.dialect != "sqlite":
-            check = True
-        if settings.instance.dialect != "sqlite" and isettings.dialect == "sqlite":
-            check = True
-    # the following is problematic as it requires importing lnschema_core at a point
-    # when settings has not yet been written to disk
-    # if isettings.dialect != "sqlite" and User.__table__.schema is None:
-    #     check = True
-    # if isettings.dialect == "sqlite" and User.__table__.schema is not None:
-    #     check = True
+def persist_settings_load_schema(isettings: InstanceSettings):
+    # The reason for why the following two calls should always come together
+    # is that the schema modules need information about what type of database
+    # (sqlite or not) is mounted at time of importing the module!
+    # hence, the schema modules look for the settings file that is generated
+    # by calling isettings._persist()
     isettings._persist()
-    if check:
-        load_schema(isettings, reload=True)
+    load_schema(isettings)
 
 
 ERROR_SQLITE_CACHE = """
@@ -144,7 +133,7 @@ def init(
         elif isinstance(result, str):
             raise RuntimeError(f"Creating instance on hub failed:\n{result}")
 
-    persist_check_reload_schema(isettings)
+    persist_settings_load_schema(isettings)
 
     # some legacy instances not yet registered in hub may actually exist
     # despite being not loadable above
